==> watset-2.3.0-sources.jar: org/nlpub/watset/cli/ChineseWhispersCommand.java <==
/*
 * Copyright 2018 Dmitry Ustalov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.nlpub.watset.cli;

import com.beust.jcommander.Parameter;
import com.beust.jcommander.Parameters;
import org.jgrapht.alg.interfaces.ClusteringAlgorithm;
import org.jgrapht.graph.DefaultWeightedEdge;
import org.nlpub.watset.graph.ChineseWhispers;
import org.nlpub.watset.graph.NodeWeightings;

/**
 * A command that runs Chinese Whispers.
 */
@Parameters(commandDescription = "Chinese Whispers")
class ChineseWhispersCommand extends ClusteringCommand {
    @SuppressWarnings({"unused", "FieldMayBeFinal"})
    @Parameter(description = "Node weighting mode (top, log, lin)", names = {"-m", "--mode"})
    private String mode = NodeWeightings.WeightingMode.TOP.name();

    @SuppressWarnings({"FieldMayBeFinal", "FieldCanBeLocal"})
    @Parameter(description = "Number of iterations", names = {"-i", "--iterations"})
    private int iterations = ChineseWhispers.Builder.ITERATIONS;

    /**
     * Create an instance of command.
     *
     * @param parameters the parameters
     */
    public ChineseWhispersCommand(MainParameters parameters) {
        super(parameters);
    }

    @Override
    public ClusteringAlgorithm<String> getAlgorithm() {
        return ChineseWhispers.<String, DefaultWeightedEdge>builder().
                setWeighting(NodeWeightings.parse(mode)).
                setIterations(iterations).
                setRandom(parameters.random).
                apply(getGraph());
    }
}

==> watset-2.8.2-sources.jar: org/nlpub/watset/cli/ChineseWhispersCommand.java <==
/*
 * Copyright 2018 Dmitry Ustalov
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.nlpub.watset.cli;

import com.beust.jcommander.Parameter;
import com.beust.jcommander.Parameters;
import org.jgrapht.alg.interfaces.ClusteringAlgorithm;
import org.jgrapht.graph.DefaultWeightedEdge;
import org.nlpub.watset.graph.ChineseWhispers;
import org.nlpub.watset.graph.NodeWeightings;

/**
 * A command that runs Chinese Whispers.
 */
@Parameters(commandDescription = "Chinese Whispers")
class ChineseWhispersCommand extends ClusteringCommand {
    @SuppressWarnings({"unused", "FieldMayBeFinal"})
    @Parameter(description = "Node weighting mode (top, log, lin)", names = {"-m", "--mode"})
    private String mode = NodeWeightings.WeightingMode.TOP.name();

    @SuppressWarnings({"FieldMayBeFinal", "FieldCanBeLocal"})
    @Parameter(description = "Number of iterations", names = {"-n", "--iterations"})
    private int iterations = ChineseWhispers.Builder.ITERATIONS;

    /**
     * Create an instance of command.
     *
     * @param parameters the parameters
     */
    public ChineseWhispersCommand(MainParameters parameters) {
        super(parameters);
    }

    @Override
    public ClusteringAlgorithm<String> getAlgorithm() {
        return ChineseWhispers.<String, DefaultWeightedEdge>builder().
                setWeighting(NodeWeightings.parse(mode)).
                setIterations(iterations).
                setRandom(parameters.random).
                apply(getGraph());
    }
}
